Changes made to bug 355

Bugzilla – Activity log for bug 355: Mock bug for testing purposes

- Home
- | New
- | Browse
- | Search
- | [?]
- | Reports
- | Preferences
- | Log out sduenas@example.com

Back to bug 355

Who | When | What | Removed | Added
--- | --- | --- | --- | ---
sduenas@example.org | 2013-06-25 11:57:23 CEST | Attachment #172 Attachment is obsolete | 0 | 1
sduenas@example.org | 2013-06-25 11:59:07 CEST | Priority | medium | high
Status | UNCONFIRMED | RESOLVED
CC | kesitesting@example.com |
Hardware | All | Macintosh
Blocks | 354 |
Depends on | 350 |
Assignee | sduenas@example.org | dizquierdo@example.com
Resolution | --- | FIXED
QA Contact | lcanas@example.com | dizquierdo@example.com
Severity | normal | trivial
OS | All | Mac OS
dizquierdo@example.com | 2013-06-25 12:04:11 CEST | Blocks |  | 354, 349
Depends on |  | 350

Back to bug 355